@@ -1,12 +1,19 @@
 # @Author: chunyang.xu
 # @Email:  398745129@qq.com
 # @Date:   2020-06-04 10:58:54
-# @Last Modified time: 2020-12-01 18:42:13
+# @Last Modified time: 2022-08-11 15:09:09
 # @github: https://github.com/longfengpili
 
 # !/usr/bin/env python3
 # -*- coding:utf-8 -*-
 
+import os
+import logging.config
+from pydbapi.conf.settings import LOGGING_CONFIG
+logging.config.dictConfig(LOGGING_CONFIG)
+
+os.environ['NUMEXPR_MAX_THREADS'] = '16'
+
 # from pydbapi.api import SqliteDB, RedshiftDB, MysqlDB, SnowflakeDB
 # from pydbapi.sql import SqlParse, SqlCompile, SqlFileParse, ColumnModel, ColumnsModel
 
